@@ -68,6 +68,7 @@ from schooltool.gradebook.browser.worksheet import FlourishWorksheetEditView
 from schooltool.gradebook.browser.pdf_views import FlourishGradebookPDFView
 from schooltool.gradebook.browser.pdf_views import WorksheetGrid
 from schooltool.person.interfaces import IPerson
+from schooltool.person.interfaces import IPersonFactory
 from schooltool.report.browser.report import RequestRemoteReportDialog
 from schooltool.report.report import ReportTask
 from schooltool.schoolyear.interfaces import ISchoolYearContainer
@@ -93,6 +94,8 @@ from schooltool.cando.interfaces import ILayerContainer
 from schooltool.cando.interfaces import INode
 from schooltool.cando.interfaces import INodeContainer
 from schooltool.cando.interfaces import ISkillsGradebook
+from schooltool.cando.interfaces import IMySkillsGrades
+from schooltool.cando.interfaces import IMyProjectsGrades
 from schooltool.cando.interfaces import IStudentIEP
 from schooltool.cando.interfaces import IDocumentContainer
 from schooltool.cando.interfaces import ICanDoStudentGradebook
@@ -330,6 +333,33 @@ class CanDoModesViewlet(flourish.viewlet.Viewlet):
         return self.template(*args, **kw)
 
 
+class MyGradesCanDoModes(flourish.page.RefineLinksViewlet):
+
+    pass
+
+
+class MyGradesCanDoModesViewlet(CanDoModesViewlet):
+
+    def items(self):
+        section = ISection(proxy.removeSecurityProxy(self.context))
+        section_url = absoluteURL(section, self.request)
+        result = []
+        if ISectionSkills(section):
+            result.append({
+                    'id': 'skills',
+                    'label': _('Skill Sets'),
+                    'url': section_url + '/mygrades-skills',
+                    'selected': IMySkillsGrades.providedBy(self.context),
+                    })
+        result.append({
+                'id': 'projects',
+                'label': _('Projects'),
+                'url': section_url + '/mygrades-projects',
+                'selected': IMyProjectsGrades.providedBy(self.context),
+                })
+        return result
+
+
 class SkillAddLink(flourish.page.LinkViewlet):
 
     @property
@@ -394,11 +424,11 @@ class ProjectAddView(flourish.form.AddForm):
 
 class CanDoNamePopupMenuView(FlourishNamePopupMenuView):
 
-    def options(self, worksheet):
+    def options(self, worksheet, column_id='student'):
         options = [
             {
                 'label': self.translate(_('Sort by')),
-                'url': '?sort_by=student',
+                'url': '?sort_by=%s' % column_id,
                 },
             ]
         return options
@@ -1427,6 +1457,11 @@ class MySkillsGradesView(FlourishMyGradesView):
         return shortTitle, longTitle, bestScore
 
 
+class MyProjectsGradesView(MySkillsGradesView):
+
+    pass
+
+
 class SkillSortingColumn(table.column.LocaleAwareGetterColumn):
 
     def getSortKey(self, item, formatter):
@@ -2229,9 +2264,9 @@ class StudentCompetencySectionReportPDFStory(flourish.report.PDFStory):
         collator = ICollator(self.request.locale)
         gradebook = proxy.removeSecurityProxy(self.context)
         section = gradebook.section
-        for student in sorted(section.members,
-                              key=lambda x: x.title,
-                              cmp=collator.cmp):
+        factory = getUtility(IPersonFactory)
+        sorting_key = lambda x: factory.getSortingKey(x, collator)
+        for student in sorted(section.members, key=sorting_key):
             student_gradebook = getMultiAdapter((student, gradebook),
                                                 ICanDoStudentGradebook)
             student_scr = getMultiAdapter(
